import requests
import random
import time
import json


class ClientGPT:
  def __init__(self):
    self.chat_id = f"6{random.randint(1000, 9999)}5333004999ceadf1076"
    self.prompt = ""

  def send_message(self, message):
    data = {"question": f"({self.prompt}){message}","chat_id": self.chat_id,"timestamp": time.time()}

    res = requests.post('https://chat.chatgptdemo.net/chat_api_stream', json=data)
    res_parts = "["+res.text.replace('data: ', ',')[1:]+"]"
    load_data = json.loads(res_parts)

    response = ''
    for data in load_data[1:-1]:
      response += data['choices'][0]['delta']['content']
      
    return response



from setuptools import setup, find_packages

requirements = [
    "requests"
]

long_description ="""### Discord
` https://discord.gg/WR9MNs5Hqv`
### How to install?
`pip install free_gpt.py`
### How Workd"""

setup(
    name="free_pygpt",
    license="MIT",
    author="nxSlayer",
    version="1.3.0",
    author_email="princediscordslay@gmail.com",
    description="Library for use free gpt 3.5 in python",
    url="https://github.com/nxSlayer/free_gpt",
    packages=find_packages(),
    long_description=long_description,
    install_requires=requirements,
    keywords=[
        'free_pygpt',
        'free-gpt',
        'freegpt',
        'free_gpt.py',
        'free_gpt'
    ],
    python_requires='>=3.6',
)


#Using template from https://github.com/Minori101/Amino.fix/blob/main/aminofix/__init__.py :D THANKS

__title__ = 'free-pygpt'
__author__ = 'nxSlayer'
__license__ = 'MIT'
__copyright__ = 'Copyright 2023 nxSlayer'


from requests import get
from json import loads

__newest__ = loads(get("https://pypi.org/pypi/free-pygpt/json").text)["info"]["version"]

if '1.3.0' != __newest__:
    print(f"(free-gpt) There is a new version, please update for better results")